Skip to contents

Returns the Upsilon effect size (Lachowicz, Preacher & Kelley, 2018), an R-squared-type measure representing the variance in Y explained indirectly by X through M.

Usage

Upsilon(res, ...)

# S3 method for class 'rmedsem'
Upsilon(res, adjusted = TRUE, ...)

Arguments

res

fitted rmedsem object

...

additional arguments (currently unused)

adjusted

logical; if TRUE (default), return the bias-adjusted estimator; if FALSE, return the unadjusted estimator

Value

A numeric scalar giving the Upsilon effect size, an R-squared-type measure of the variance in the dependent variable explained indirectly through the mediator.

Examples

mod.txt <- "
read ~ math
science ~ read + math
"
mod <- lavaan::sem(mod.txt, data=rmedsem::hsbdemo)
out <- rmedsem(mod, indep="math", med="read", dep="science",
               effect.size=c("RIT","RID","upsilon"))
Upsilon(out)
#> [1] 0.06073778
Upsilon(out, adjusted=FALSE)
#> [1] 0.06280834