Skip to contents

Data from a survey on mate-choice in Trondheim.

Usage

mchoice

Format

mchoice

A data frame with 1090 rows and 9 columns:

smv_attr_face

How well does this describe you as a partner?, [1] very bad - [5] very well

smv_attr_body

How well does this describe you as a partner?, [1] very bad - [5] very well

smv_sexy

How well does this describe you as a partner?, [1] very bad - [5] very well

ses_satis

On the whole, I am satisfied with myself, [1] totally disgree - [5] totally agree

ses_qualities

I feel that I have a number of good qualities, [1] totally disgree - [5] totally agree

ses_able_todo

I am able to do things as well as most other people, [1] totally disgree - [5] totally agree

mwb_optimistic

I have been feeling optimistic about the future, [1] never - [5] always

mwb_useful

I have been feeling useful, [1] never - [5] always

mwb_energy

I have had energy to spare, [1] never - [5] always

smv_kind

?, [1] ? - [5] ?

smv_caring

?, [1] ? - [5] ?

smv_understanding

?, [1] ? - [5] ?

smv_make_laughh

?, [1] ? - [5] ?

smv_funny

?, [1] ? - [5] ?

smv_sociable

?, [1] ? - [5] ?