Visualize the results of rmedsem().
Arguments
- x, res
an
rmedsemobject- type
character;
"coef"(default) for a coefficient plot or"effect"for an effect size plot- ...
additional arguments passed to
plot_coef()orplot_effect()- description
logical, whether to add a caption describing the proportion of the total effect that is mediated (default
TRUE)
Details
plot_coef()A coefficient plot of the indirect effect (for each estimation method), the direct effect and the total effect, with their confidence (or credible) intervals.
plot_effect()A pie chart of the (absolute) indirect and direct effects, i.e., the proportion of the total effect that is mediated. Requires the effect sizes
"RIT"and"RID".
plot() calls plot_coef() (type = "coef") or plot_effect()
(type = "effect").